@@ -24,11 +24,17 @@ def clear_collection(db: "firestore.Client", ref):
     batch.commit()
 
 
+def valid(id: str):
+    if "/" in id or ".." in id:
+        raise Exception("Invalid id!")
+    return id
+
+
 @server_only
 def get_exam(*, exam):
     try:
         db = firestore.Client()
-        out = db.collection("exams").document(exam).get().to_dict()
+        out = db.collection("exams").document(valid(exam)).get().to_dict()
         if "secret" in out and isinstance(out["secret"], bytes):
             out["secret"] = out["secret"].decode("utf-8")
         return out
@@ -39,7 +45,7 @@ def get_exam(*, exam):
 @server_only
 def set_exam(*, exam, json):
     db = firestore.Client()
-    db.collection("exams").document(exam).set(json)
+    db.collection("exams").document(valid(exam)).set(json)
 
     ref = db.collection("exams").document("all")
     data = ref.get().to_dict()
@@ -53,7 +59,7 @@ def set_exam(*, exam, json):
 def get_roster(*, exam):
     db = firestore.Client()
     for student in (
-        db.collection("roster").document(exam).collection("deadline").stream()
+        db.collection("roster").document(valid(exam)).collection("deadline").stream()
     ):
         yield student.id, student.to_dict()["deadline"]
 
@@ -62,7 +68,7 @@ def get_roster(*, exam):
 def set_roster(*, exam, roster):
     db = firestore.Client()
 
-    ref = db.collection("roster").document(exam).collection("deadline")
+    ref = db.collection("roster").document(valid(exam)).collection("deadline")
 
     batch = db.batch()
     cnt = 0
@@ -78,7 +84,7 @@ def set_roster(*, exam, roster):
     batch = db.batch()
     cnt = 0
     for email, deadline in roster:
-        doc_ref = ref.document(email)
+        doc_ref = ref.document(valid(email))
         batch.set(doc_ref, {"deadline": int(deadline)})
         cnt += 1
         if cnt > 400:
@@ -93,7 +99,7 @@ def set_roster(*, exam, roster):
 def get_submissions(*, exam):
     db = firestore.Client()
 
-    for ref in db.collection(exam).stream():
+    for ref in db.collection(valid(exam)).stream():
         yield ref.id, ref.to_dict()
 
 
@@ -102,7 +108,9 @@ def get_submissions(*, exam):
 def get_logs(*, exam, email):
     db = firestore.Client()
 
-    for ref in db.collection(exam).document(email).collection("log").stream():
+    for ref in (
+        db.collection(valid(exam)).document(valid(email)).collection("log").stream()
+    ):
         yield ref.to_dict()
 
 
@@ -134,15 +142,17 @@ def process_ok_exam_upload(*, exam, data, clear=True):
     """
     db = firestore.Client()
 
-    db.collection("exam-alerts").document(exam).set({"questions": data["questions"]})
-    ref = db.collection("exam-alerts").document(exam).collection("students")
+    db.collection("exam-alerts").document(valid(exam)).set(
+        {"questions": data["questions"]}
+    )
+    ref = db.collection("exam-alerts").document(valid(exam)).collection("students")
     if clear:
         clear_collection(db, ref)
 
     batch = db.batch()
     cnt = 0
     for student in data["students"]:
-        doc_ref = ref.document(student["email"])
+        doc_ref = ref.document(valid(student["email"]))
         batch.set(doc_ref, student)
         cnt += 1
         if cnt > BATCH_SIZE:
