@@ -21,21 +21,40 @@ def write_exam(
     sid_question,
     dispatch,
     out=None,
+    substitute_in_question_text=False,
 ):
     pdf = FPDF()
     pdf.add_page()
 
     pdf.set_font("Courier", size=16)
     pdf.multi_cell(200, 20, txt=exam, align="L")
-    pdf.multi_cell(200, 20, txt=response.get(name_question, "NO NAME").encode("latin-1", "replace").decode("latin-1"), align="L")
-    pdf.multi_cell(200, 20, txt=response.get(sid_question, "NO SID").encode("latin-1", "replace").decode("latin-1"), align="L")
+    pdf.multi_cell(
+        200,
+        20,
+        txt=response.get(name_question, "NO NAME")
+        .encode("latin-1", "replace")
+        .decode("latin-1"),
+        align="L",
+    )
+    pdf.multi_cell(
+        200,
+        20,
+        txt=response.get(sid_question, "NO SID")
+        .encode("latin-1", "replace")
+        .decode("latin-1"),
+        align="L",
+    )
 
     pdf.set_font("Courier", size=9)
 
     if out is None:
+
         def out(text):
             pdf.multi_cell(
-                200, 5, txt=text.encode("latin-1", "replace").decode("latin-1"), align="L"
+                200,
+                5,
+                txt=text.encode("latin-1", "replace").decode("latin-1"),
+                align="L",
             )
 
     student_question_lookup = {q["id"]: q for q in student_questions}
@@ -43,7 +62,11 @@ def write_exam(
     for question in template_questions:
         pdf.add_page()
         out("\nQUESTION")
-        for line in question["text"].split("\n"):
+        if substitute_in_question_text:
+            question_for_text = student_question_lookup.get(question["id"], question)
+        else:
+            question_for_text = question
+        for line in question_for_text["text"].split("\n"):
             out(line)
 
         out("\nANSWER")
@@ -114,6 +137,7 @@ def export(
     sid_question,
     dispatch=None,
     include_outline=True,
+    substitute_in_question_text=False,
 ):
     out = out or "out/export/" + exam
     pathlib.Path(out).mkdir(parents=True, exist_ok=True)
@@ -141,6 +165,7 @@ def export(
             name_question,
             sid_question,
             dispatch,
+            substitute_in_question_text=substitute_in_question_text,
         )
         pdf.output(os.path.join(out, "{}.pdf".format(email)))
 
