@@ -12,14 +12,27 @@ from examtool.api.database import get_exam, get_roster
 from examtool.api.utils import sanitize_email
 from examtool.api.scramble import scramble
 from examtool.api.gen_latex import render_latex
-from examtool.cli.utils import determine_semester, exam_name_option, hidden_output_folder_option, prettify
+from examtool.cli.utils import (
+    determine_semester,
+    exam_name_option,
+    hidden_output_folder_option,
+    prettify,
+)
 
 
 @click.command()
 @exam_name_option
-@click.option("--subtitle", prompt=True, default="Structure and Interpretation of Computer Programs")
+@click.option(
+    "--subtitle",
+    prompt=True,
+    default="Structure and Interpretation of Computer Programs",
+)
 @hidden_output_folder_option
-@click.option("--do-twice", is_flag=True, help="Run the compile twice for each student to fix weird rendering bugs.")
+@click.option(
+    "--do-twice",
+    is_flag=True,
+    help="Run the compile twice for each student to fix weird rendering bugs.",
+)
 @click.option("--email", help="The email address of a particular student.")
 @click.option(
     "--exam-type",
@@ -31,7 +44,11 @@ from examtool.cli.utils import determine_semester, exam_name_option, hidden_outp
     default=determine_semester(),
     help=f"The semester of the exam. '{determine_semester()}' (default).",
 )
-@click.option("--deadline", default=None, help="Generates exam regardless of if student is in roster with the set deadline.")
+@click.option(
+    "--deadline",
+    default=None,
+    help="Generates exam regardless of if student is in roster with the set deadline.",
+)
 def compile_all(exam, subtitle, out, do_twice, email, exam_type, semester, deadline):
     """
     Compile individualized PDFs for the specified exam.
@@ -46,7 +63,7 @@ def compile_all(exam, subtitle, out, do_twice, email, exam_type, semester, deadl
     password = exam_data.pop("secret")[:-1]
     print(password)
     exam_str = json.dumps(exam_data)
-    
+
     roster = get_roster(exam=exam)
 
     if email:
@@ -57,7 +74,6 @@ def compile_all(exam, subtitle, out, do_twice, email, exam_type, semester, deadl
             else:
                 raise ValueError("Email does not exist in the roster!")
 
-
     for email, deadline in roster:
         if not deadline:
             continue
