@@ -13,5 +13,5 @@ def login():
     print("Token automatically saved")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     login()
