@@ -59,12 +59,17 @@ def send(exam, target, email, subject, filename):
 
     key = get_api_key(exam=exam)
 
-    print((
-        "Subject: {subject}\n"
-        "PDF filename: {filename}\n"
-        "Body: {body}\n\n"
-    ).format(body=body, filename=filename, subject=subject))
-    if input("Sending email to {} people - confirm? (y/N) ".format(len(roster))).lower() != "y":
+    print(
+        ("Subject: {subject}\n" "PDF filename: {filename}\n" "Body: {body}\n\n").format(
+            body=body, filename=filename, subject=subject
+        )
+    )
+    if (
+        input(
+            "Sending email to {} people - confirm? (y/N) ".format(len(roster))
+        ).lower()
+        != "y"
+    ):
         exit(1)
 
     for email in roster:
@@ -72,14 +77,12 @@ def send(exam, target, email, subject, filename):
             os.path.join(
                 target, "exam_" + email.replace("@", "_").replace(".", "_") + ".pdf"
             ),
-            "rb"
+            "rb",
         ) as f:
             pdf = base64.b64encode(f.read()).decode("ascii")
         data = {
             "from": {"email": "cs61a@berkeley.edu", "name": "CS 61A Exam Platform"},
-            "personalizations": [
-                {"to": [{"email": email}], "substitutions": {}}
-            ],
+            "personalizations": [{"to": [{"email": email}], "substitutions": {}}],
             "subject": subject,
             "content": [{"type": "text/plain", "value": body}],
             "attachments": [
